@@ -90,8 +90,11 @@ class ICP(BaseAnalysisBlock):
             icp = icp_class(nc, cal_size=self.validation_size)
 
             output['icp']['__default'] = icp
+            icp_df = deepcopy(ns.data)
 
             # setup prediction cache to avoid additional .predict() calls
+            pred_is_list = isinstance(ns.normal_predictions['prediction'], list) and \
+                isinstance(ns.normal_predictions['prediction'][0], list)
             if ns.is_classification:
                 if ns.predictor.supports_proba:
                     icp.nc_function.model.prediction_cache = ns.normal_predictions[all_cat_cols].values
@@ -105,7 +108,7 @@ class ICP(BaseAnalysisBlock):
                     predicted_classes = pd.get_dummies(preds).values  # inflate to one-hot enc
                     icp.nc_function.model.prediction_cache = predicted_classes
 
-            elif ns.is_multi_ts:
+            elif ns.is_multi_ts or pred_is_list:
                 # we fit ICPs for time series confidence bounds only at t+1 forecast
                 icp.nc_function.model.prediction_cache = np.array([p[0] for p in ns.normal_predictions['prediction']])
             else:
@@ -116,6 +119,9 @@ class ICP(BaseAnalysisBlock):
 
             # fit additional ICPs in time series tasks with grouped columns
             if ns.tss.is_timeseries and ns.tss.group_by:
+                # generate a multiindex
+                midx = pd.MultiIndex.from_frame(icp_df[[*ns.tss.group_by, f'__mdb_original_{ns.tss.order_by[0]}']])
+                icp_df.index = midx
 
                 # create an ICP for each possible group
                 group_info = ns.data[ns.tss.group_by].to_dict('list')
@@ -127,7 +133,6 @@ class ICP(BaseAnalysisBlock):
                     output['icp'][tuple(combination)] = deepcopy(icp)
 
             # calibrate ICP
-            icp_df = deepcopy(ns.data)
             icp_df, y = clean_df(icp_df, ns.target, ns.is_classification, output.get('label_encoders', None))
             output['icp']['__default'].index = icp_df.columns
             output['icp']['__default'].calibrate(icp_df.values, y)
@@ -137,11 +142,11 @@ class ICP(BaseAnalysisBlock):
                 icp_df, icp, ns.dtype_dict[ns.target],
                 output, positive_domain=self.positive_domain, significance=self.fixed_significance)
             if not ns.is_classification:
-                result_df = pd.DataFrame(index=ns.data.index, columns=['confidence', 'lower', 'upper'], dtype=float)
+                result_df = pd.DataFrame(index=icp_df.index, columns=['confidence', 'lower', 'upper'], dtype=float)
                 result_df.loc[icp_df.index, 'lower'] = ranges[:, 0]
                 result_df.loc[icp_df.index, 'upper'] = ranges[:, 1]
             else:
-                result_df = pd.DataFrame(index=ns.data.index, columns=['confidence'], dtype=float)
+                result_df = pd.DataFrame(index=icp_df.index, columns=['confidence'], dtype=float)
 
             result_df.loc[icp_df.index, 'confidence'] = conf
 
@@ -152,10 +157,12 @@ class ICP(BaseAnalysisBlock):
 
                 # add all predictions to DF
                 icps_df = deepcopy(ns.data)
-                if ns.is_multi_ts:
-                    icps_df[f'__predicted_{ns.target}'] = [p[0] for p in ns.normal_predictions['prediction']]
+                midx = pd.MultiIndex.from_frame(icps_df[[*ns.tss.group_by, f'__mdb_original_{ns.tss.order_by[0]}']])
+                icps_df.index = midx
+                if ns.is_multi_ts or pred_is_list:
+                    icps_df[f'__predicted_{ns.target}'] = np.array([p[0] for p in ns.normal_predictions['prediction']])
                 else:
-                    icps_df[f'__predicted_{ns.target}'] = ns.normal_predictions['prediction']
+                    icps_df[f'__predicted_{ns.target}'] = np.array(ns.normal_predictions['prediction'])
 
                 for group in icps['__mdb_groups']:
                     icp_df = icps_df
@@ -207,6 +214,7 @@ class ICP(BaseAnalysisBlock):
             # consolidate all groups here
             output['icp']['__mdb_active'] = True
 
+        result_df.index = ns.data.index
         output['result_df'] = result_df
 
         info = {**info, **output}
@@ -216,12 +224,21 @@ class ICP(BaseAnalysisBlock):
                 **kwargs) -> Tuple[pd.DataFrame, Dict[str, object]]:
         ns = SimpleNamespace(**kwargs)
 
+        if 'confidence' in ns.predictions.columns:
+            # bypass calibrator if model already outputs confidence
+            row_insights['prediction'] = ns.predictions['prediction']
+            row_insights['confidence'] = ns.predictions['confidence']
+            if 'upper' in ns.predictions.columns and 'lower' in ns.predictions.columns:
+                row_insights['upper'] = ns.predictions['upper']
+                row_insights['lower'] = ns.predictions['lower']
+            return row_insights, global_insights
+
         if ns.analysis['icp']['__mdb_active']:
             icp_X = deepcopy(ns.data)
 
             # replace observed data w/predictions
             preds = ns.predictions['prediction']
-            if ns.tss.is_timeseries and ns.tss.horizon > 1:
+            if ns.tss.is_timeseries and (ns.tss.horizon > 1 or isinstance(preds[0], list)):
                 preds = [p[0] for p in preds]
 
                 for col in [f'timestep_{i}' for i in range(1, ns.tss.horizon)]:
